hstrat.hstrat.stratum\_retention\_condemners.StratumRetentionCondemnerRecencyProportionalResolution
===================================================================================================

.. currentmodule:: hstrat.hstrat.stratum_retention_condemners

.. autoclass:: StratumRetentionCondemnerRecencyProportionalResolution

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~StratumRetentionCondemnerRecencyProportionalResolution.CalcMrcaUncertaintyUpperBound
      ~StratumRetentionCondemnerRecencyProportionalResolution.CalcNumStrataRetainedExact
      ~StratumRetentionCondemnerRecencyProportionalResolution.CalcNumStrataRetainedUpperBound
      ~StratumRetentionCondemnerRecencyProportionalResolution.CalcRankAtColumnIndex
      ~StratumRetentionCondemnerRecencyProportionalResolution.__init__
   
   

   
   
   